@@ -4,6 +4,15 @@
 #
 ###############################################################################
 
+AbstractAlgebra.Solve.matrix_normal_form_type(::AbsSimpleNumField) = AbstractAlgebra.Solve.FFLUTrait()
+function AbstractAlgebra.Solve._common_denominator(A::MatElem{AbsSimpleNumFieldElem}) 
+  return base_ring(A)(mapreduce(denominator, lcm, A; init = ZZ(1)))
+end
+function AbstractAlgebra.Solve.solve_context_type(::AbstractAlgebra.Solve.FFLUTrait, ::Type{AbsSimpleNumFieldElem})
+   MatType = dense_matrix_type(AbsSimpleNumFieldElem)
+   return AbstractAlgebra.Solve.SolveCtx{AbsSimpleNumFieldElem, AbstractAlgebra.Solve.FFLUTrait, MatType, MatType, MatType}
+end
+
 ###############################################################################
 #
 #   Type and parent object methods
@@ -1036,6 +1045,12 @@ function (a::QQPolyRing)(b::AbsSimpleNumFieldElem)
   return r
 end
 
+function lift(a::QQPolyRing, b::AbsSimpleNumFieldElem)
+  r = a()
+  @ccall libflint.nf_elem_get_fmpq_poly(r::Ref{QQPolyRingElem}, b::Ref{AbsSimpleNumFieldElem}, parent(b)::Ref{AbsSimpleNumField})::Nothing
+  return r
+end
+
 (::QQField)(a::AbsSimpleNumFieldElem) = (is_rational(a) && return coeff(a, 0)) || error("not a rational")
 
 (::ZZRing)(a::AbsSimpleNumFieldElem) = (is_integer(a) && return numerator(coeff(a, 0))) || error("not an integer")
