@@ -123,11 +123,8 @@ function coeff(a::QQMPolyRingElem, b::QQMPolyRingElem)
 end
 
 function trailing_coefficient(p::QQMPolyRingElem)
-  if iszero(p)
-    return zero(base_ring(p))
-  else
-    return coeff(p, length(p))
-  end
+  @req !iszero(p) "Zero polynomial does not have a leading monomial"
+  return coeff(p, length(p))
 end
 
 ###############################################################################
