@@ -140,6 +140,80 @@ function reverse_cols!(x::T) where T <: Zmod_fmpz_mat
   return x
 end
 
+###############################################################################
+#
+#   manual linear algebra: row and col operations
+#
+###############################################################################
+function AbstractAlgebra.multiply_row!(A::Zmod_fmpz_mat, s::ZZModRingElem, i::Int, cols::UnitRange{Int}=1:ncols(A))
+  @assert 1 <= i <= nrows(A)
+  @assert 1 <= first(cols) && last(cols) <= ncols(A)
+  c = first(cols)
+  ctx = base_ring(A).ninv
+  GC.@preserve A begin
+    # these are Ptr{ZZRingElem}
+    i_ptr = mat_entry_ptr(A, i, c)
+    for k = cols
+      @ccall libflint.fmpz_mod_mul(i_ptr::Ref{ZZRingElem}, i_ptr::Ref{ZZRingElem}, lift(s)::Ref{ZZRingElem}, ctx::Ref{fmpz_mod_ctx_struct})::Nothing
+      i_ptr += sizeof(ZZRingElem)
+    end
+  end
+end
+
+function AbstractAlgebra.multiply_column!(A::Zmod_fmpz_mat, s::ZZModRingElemOrPtr, i::Int, j::Int, rows::UnitRange{Int}=1:nrows(A))
+  @assert 1 <= j <= ncols(A)
+  @assert 1 <= first(rows)
+  @assert last(rows) <= nrows(A)
+  ctx = base_ring(A).ninv
+  GC.@preserve A begin
+    for k = rows
+      i_ptr = mat_entry_ptr(A, k, i)
+      @ccall libflint.fmpz_mod_mul(i_ptr::Ref{ZZRingElem}, i_ptr::Ref{ZZRingElem}, lift(s)::Ref{ZZRingElem}, ctx::Ref{fmpz_mod_ctx_struct})::Nothing
+    end
+  end
+end
+
+
+function AbstractAlgebra.add_row!(A::Zmod_fmpz_mat, s::ZZModRingElem, i::Int, j::Int, cols::UnitRange{Int}=1:ncols(A))
+  @assert 1 <= i <= nrows(A)
+  @assert 1 <= j <= nrows(A)
+  @assert 1 <= first(cols) && last(cols) <= ncols(A)
+  c = first(cols)
+  ctx = base_ring(A).ninv
+  GC.@preserve A begin
+    # these are Ptr{ZZRingElem}
+    i_ptr = mat_entry_ptr(A, i, c)
+    j_ptr = mat_entry_ptr(A, j, c)
+    for k = cols
+      # there is no addmul for fmpz_mod in flint
+      # we use the one for fmpz and reduce afterwards
+      addmul!(j_ptr, lift(s), i_ptr)
+      @ccall libflint.fmpz_mod_set_fmpz(j_ptr::Ref{ZZRingElem}, j_ptr::Ref{ZZRingElem}, ctx::Ref{fmpz_mod_ctx_struct})::Nothing
+      i_ptr += sizeof(ZZRingElem)
+      j_ptr += sizeof(ZZRingElem)
+    end
+  end
+end
+
+function AbstractAlgebra.add_column!(A::Zmod_fmpz_mat, s::ZZModRingElemOrPtr, i::Int, j::Int, rows::UnitRange{Int}=1:nrows(A))
+  @assert 1 <= i <= ncols(A)
+  @assert 1 <= j <= ncols(A)
+  @assert 1 <= first(rows)
+  @assert last(rows) <= nrows(A)
+  ctx = base_ring(A).ninv
+  GC.@preserve A begin
+    for k = rows
+      # there is no addmul for fmpz_mod in flint
+      # we use the one for fmpz and reduce afterwards
+      # these are Ptr{ZZRingElem}
+      i_ptr = mat_entry_ptr(A, k, i)
+      j_ptr = mat_entry_ptr(A, k, j)
+      addmul!(j_ptr, lift(s), i_ptr)
+      @ccall libflint.fmpz_mod_set_fmpz(j_ptr::Ref{ZZRingElem}, j_ptr::Ref{ZZRingElem}, ctx::Ref{fmpz_mod_ctx_struct})::Nothing
+    end
+  end
+end
+
 ################################################################################
 #
 #  Unary operators
