@@ -115,12 +115,9 @@ function coeff(a::ZZMPolyRingElem, b::ZZMPolyRingElem)
   return z
 end
 
-function trailing_coefficient(p::ZZPolyRingElem)
-  if iszero(p)
-    return zero(base_ring(p))
-  else
-    return coeff(p, length(p))
-  end
+function trailing_coefficient(p::ZZMPolyRingElem)
+  @req !iszero(p) "Zero polynomial does not have a leading monomial"
+  return coeff(p, length(p))
 end
 
 ###############################################################################
@@ -643,7 +640,7 @@ function set!(z::ZZMPolyRingElem, a::UInt)
   return z
 end
 
-set!(z::ZZMPolyRingElem, a::Union{Integer, Rational}) = set!(z, flintify(a))
+set!(z::ZZMPolyRingElem, a::Integer) = set!(z, flintify(a))
 
 #
 
